@@ -4,7 +4,7 @@
  *
  * Copyright 2002 Ximian, Inc.
  *           2002 Sun Microsystems Inc.
- *           
+ *
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,20 +25,19 @@
 #ifndef _ATSPI_PRIVATE_H_
 #define _ATSPI_PRIVATE_H_
 
-#include <config.h>
 #include "atspi-device-listener-private.h"
 #include "atspi-event-listener-private.h"
 #include "atspi-matchrule-private.h"
 #include "atspi-misc-private.h"
-#include "atspi-mutter-private.h"
+#include <config.h>
 
 #include "glib/gi18n.h"
 
-#include "atspi.h"
 #include "atspi-accessible-private.h"
+#include "atspi.h"
 
 G_BEGIN_DECLS
 void _atspi_reregister_device_listeners ();
 G_END_DECLS
 
-#endif	/* _ATSPI_PRIVATE_H_ */
+#endif /* _ATSPI_PRIVATE_H_ */
