@@ -191,6 +191,7 @@ set_reply (DBusPendingCall *pending, void *user_data)
   void **replyptr = (void **) user_data;
 
   *replyptr = dbus_pending_call_steal_reply (pending);
+  dbus_pending_call_unref (pending);
 }
 
 static DBusMessage *
@@ -302,6 +303,8 @@ main (int argc, char **argv)
   g_main_loop_run (main_loop);
 
   droute_free (cnx);
+  g_free (object->astring);
+  g_free (object);
 
   if (success)
     return 0;
